RandomRegularGenerator

Struct RandomRegularGenerator 

pub struct RandomRegularGenerator { /* private fields */ }
Generates random k-regular graphs where every vertex has the same degree.

Uses the pairing (configuration) model: create k stubs for each vertex, then randomly match stubs. Self-loops and multi-edges are discarded and re-attempted.

Implementations

Source

impl RandomRegularGenerator

pub fn new(num_vertices: usize, degree: usize, seed: u64) -> Self

Creates a new random regular graph generator.

Arguments
  • num_vertices — number of vertices
  • degree — the common degree k (n*k must be even)
  • seed — PRNG seed
pub fn generate(&self) -> RandResult<AdjacencyList>

Generates a random k-regular undirected graph.

Errors

Returns RandError::InvalidSize if num_vertices * degree is odd, or degree >= num_vertices.